
.. _`WBEM client library API`:

WBEM client library API
=======================

The WBEM client library API supports issuing WBEM operations to a WBEM server,
using the CIM operations over HTTP (CIM-XML) protocol defined in the DMTF
standards :term:`DSP0200` and :term:`DSP0201`.

A number of these topics apply also to the other APIs of the pywbem package.

**Chapter Contents**

.. toctree::
   :maxdepth: 1

   client/operations.rst
   client/objects.rst
   client/types.rst
   client/conversion.rst
   client/status.rst
   client/exceptions.rst
   client/warnings.rst
   client/statistics.rst
   client/logging.rst
   client/recording.rst
   client/valuemappings.rst
   client/security.rst
